Struct cairo_lang_defs::plugin::MacroPluginMetadata
source · pub struct MacroPluginMetadata<'a> {
pub cfg_set: &'a CfgSet,
}Expand description
A structure containing additional info about the current module item on which macro plugin operates.
Fields
cfg_set: &'a CfgSetConfig set of a crate to which the current item belongs.